Joking
======

Joking is a python library for getting random dad jokes and more kinds
of jokes

|image0| |forthebadge| |forthebadge2| |image3| |image4| |image5| |image6|
|image7| |PyPI - Downloads|

Installation
============

you can install it by using the `pip <https://pip.pypa.io/en/stable/>`__
package manager

.. code:: bash

   pip install Joking

How to Use
==========

.. code:: python

   Multiple_Jokes(i) #i is for the amount of dad jokes

.. code:: python

   random_dad_joke() #prints out a random dad joke

.. code:: python

   programming_joke() #prints a random programming joke

.. code:: python

   random_joke() #prints a random joke

.. code:: python

   sjoke() #Gets a specific joke using the joke id from https://icanhazdadjoke.com/

.. code:: python

   search_for_joke() #prints the top result for the joke you searched

How it works
============

It works by web scraping https://icanhazdadjoke.com/ and using version 2
of jokeapi.dev

Joke id's
================

Joke ids are Joke ids from icanhazdadjoke.com or from http://www.jokes4us.com/knockknockjokes/random/knockknock.html
To find a jokes id just search icanhazdadjoke.com or find the knock knock joke you want from http://www.jokes4us.com/knockknockjokes/random/knockknock.html

How to contribute
=================

Start by going to https://github.com/Iwertyuiop123653/Joker then commit.

.. |image0| image:: https://img.shields.io/badge/build-Passing-green?style=for-the-badge
.. |forthebadge| image:: https://forthebadge.com/images/badges/gluten-free.svg
.. |forthebadge2| image:: https://forthebadge.com/images/badges/powered-by-electricity.svg
.. |image3| image:: https://img.shields.io/badge/License-MIT-orange?style=for-the-badge
.. |image4| image:: https://bit.ly/3cTlr54
.. |image5| image:: https://tinyurl.com/badgesdhdh
.. |image6| image:: http://ForTheBadge.com/images/badges/made-with-python.svg
.. |image7| image:: https://tinyurl.com/emails83
.. |PyPI - Downloads| image:: https://tinyurl.com/smoler
